pygeodesy.booleans._CompositeFHP

Package pygeodesy :: Module booleans :: Class _CompositeFHP |
[frames] | no frames]

# Class _CompositeFHP

      object --+
               |
    named._Named --+
                   |
      _CompositeBase --+
                       |
                      _CompositeFHP

Known Subclasses:
  - BooleanFHP

(INTERNAL) A list of clips representing a composite of LatLonFHP points, duplicates and intersections with an other composite.

Instance Methods
__init__(self, lls, raiser=False, **name_kind_eps) (INTERNAL) See BooleanFHP and BooleanGH. |
Inherited from `_CompositeBase`: `__contains__`, `__eq__`, `__iter__`, `__len__`, `__ne__`, `__repr__`, `__str__`, `clipids`, `isequalTo`, `toLatLon` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `_CompositeBase`: `eps`, `raiser` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, lls, raiser=False, **name_kind_eps) (Constructor) |
(INTERNAL) See BooleanFHP and BooleanGH. Overrides: object.__init__ (inherited documentation)